@@ -1453,6 +1453,14 @@ int savei_filetype() {
 			case 'B':
 				return 4;
 				break;
+			case 't':
+			case 'T':
+				return 5;
+				break;
+			case 's':
+			case 'S':
+				return 5;
+				break;
 		}
 	}
 	return 0;
@@ -1491,6 +1499,65 @@ int savei_clearscreen() {
 	return 0;
 }
 
+int savei_defname(char *defname){
+	int x = 0;
+	character ch = 0;
+	int offset = 24;
+	int done = 0;
+	int i_offset = 0;
+
+	if(options.sb_top) offset = 0;
+
+	done = 0;
+	i_offset = 0;
+
+	for(x = 0; x < 80; x++)
+		mvaddch(offset, x, ansi_sb[SB_THC_DEFNAME][x]);
+
+	for(x = 0; x < 20; x++)
+		defname[x] = '\0';
+
+	for(x = 0; x < 20; x++)
+		mvaddch(offset, 19 + x, ' ');
+
+	mvaddstr(offset, 19, defname);
+
+	refresh();
+
+	while(!done) {
+		ch = n_getch();
+		ch=toupper(ch);
+		switch(ch) {
+			case KEY_BACKSPACE:
+				defname[i_offset] = '\0';
+				if(i_offset > 0) i_offset--;
+				defname[i_offset] = '\0';
+				break;
+			case 13:
+				done = 1;
+				break;
+			case '_':
+			case '-':
+				if(isprint(ch)) {
+					defname[i_offset] = ch;
+					if((i_offset+1) < 20) i_offset++;
+				}
+				break;
+			default:
+				if(isalnum(ch)) {
+					defname[i_offset] = ch;
+					if((i_offset+1) < 20) i_offset++;
+				}
+				break;
+		}
+		for(x = 0; x < 20; x++)
+			mvaddch(offset, 19 + x, ' ');
+		mvaddstr(offset, 19, defname);
+		refresh();
+	}
+	return 1;
+}
+
 /* this function gets the sauce information from the user */
 int savei_sauce(char *author, char *group, char *title) {
 	int x = 0;
@@ -2463,10 +2530,10 @@ void draw_tv_sbar(canvas *page) {
 
 void draw_num(int y, int x, int num) {
 	int count = 0;
-	char *snum = (char *)NULL;
+	char snum[100];
 	int len = 0;
 
-	asprintf(&snum, "%d", num);
+	snprintf(snum, 100, "%d", num);
 	if(!snum) return;
 	len = strlen(snum);
 
@@ -2620,18 +2687,18 @@ void draw_get_num(int y, int x, int n, char *snum) {
 
 /* this function gets a number from the user inbetween h(igh) and l(ow) */
 void get_num(int y, int x, int h, int l, int n, int *num) {
-	char *snum = (char *)NULL;
+	char snum[100];
 	int i_offset = 0;
 	character ch = 0;
-	char *prompt = (char *)NULL;
+	char prompt[1024];
 	int len = 0;
 
 
 	memset(&snum, 32, sizeof(n));
 
-	asprintf(&snum, "%d", *num);
+	snprintf(snum, 100, "%d", *num);
 
-	asprintf(&prompt, "range: %d to %d (inclusive)", l, h);
+	snprintf(prompt, 1024, "range: %d to %d (inclusive)", l, h);
 
 	len = strlen(prompt);
 
@@ -2790,12 +2857,12 @@ void draw_percentbar(int fpos, int flen) {
 	int y = 6;
 	int x = 4;
 	int percent = (float)((float)fpos / (float)flen * 100);
-	char *spercent = (char *)NULL;
+	char spercent[100];
 
 	hide_cursor();
 	if(percent < 0 || percent > 100) return;
 
-	asprintf(&spercent, "%d", percent);
+	snprintf(spercent,100, "%d", percent);
 	for(count = 0; spercent[count]; count++)
 		mvaddch(y, x + count, spercent[count] | colour_attribute(COLOUR_BLUE,
 					COLOUR_BLACK, FALSE, FALSE));
@@ -2831,16 +2898,15 @@ void draw_chselect(int page) {
 	int row = 0;
 	int column = 0;
 	attribute clr = colour_attribute(COLOUR_YELLOW, COLOUR_BLUE, TRUE, FALSE);
-	char *sascii = (char *)NULL;
+	char sascii[100];
 	int count = 0;
 
 	for(row = 0; row < 2; row++) {
 		for(column = 1; column <= 10; column++) {
 			if((20*page)+(row*10)+column <= 256) {
-					asprintf(&sascii, "%3d", (20*page)+(row*10)+column);
+					snprintf(sascii, 100, "%3d", (20*page)+(row*10)+column);
 					for(count = 0; sascii[count]; count++)
 						mvaddch(column + 3, 40+(row*10)+count, sascii[count] | clr);
-					sascii = m_free(sascii);
 
 					if(VALID_CH((20*page)+(row*10)+column))
 						mvaddch(column + 3, 45+(row*10), 
