@@ -1,8 +1,31 @@
 #ifndef _KEYS_H
 #define _KEYS_H
 
+#define NEW_KEYCODES
+
 #define TD_KEY_REDRAW 12
 
+#ifdef NEW_KEYCODES
+#define TD_KEY_HOME KEY_HOME
+#define TD_KEY_INSERT KEY_IC
+#define TD_KEY_DEL KEY_DC
+#define TD_KEY_END KEY_END
+#define TD_KEY_PAGEUP KEY_PPAGE
+#define TD_KEY_PAGEDOWN KEY_NPAGE
+
+#define TD_KEY_F1 KEY_F(1)
+#define TD_KEY_F2 KEY_F(2)
+#define TD_KEY_F3 KEY_F(3)
+#define TD_KEY_F4 KEY_F(4)
+#define TD_KEY_F5 KEY_F(5)
+#define TD_KEY_F6 KEY_F(6)
+#define TD_KEY_F7 KEY_F(7)
+#define TD_KEY_F8 KEY_F(8)
+#define TD_KEY_F9 KEY_F(9)
+#define TD_KEY_F10 KEY_F(10)
+#define TD_KEY_F11 KEY_F(11)
+#define TD_KEY_F12 KEY_F(12)
+#else
 #define TD_KEY_HOME 701
 #define TD_KEY_INSERT 702
 #define TD_KEY_DEL 703
@@ -22,6 +45,7 @@
 #define TD_KEY_F10 716
 #define TD_KEY_F11 717
 #define TD_KEY_F12 718
+#endif
 
 #define TD_KEY_BLOCK 719
 
